errbase

package
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 27, 2023 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package errbase provides a simple error type.

Example
err := New("error")
s := err.Error()
fmt.Println(s)
Output:
error

Index

Examples

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(msg string) error

New creates a new error with the given message.

It can be used as a "sentinel" error.

func Newf

func Newf(format string, args ...interface{}) error

Newf creates a new error with the given formatted message.

Types

This section is empty.

Jump to