erriter

package
v0.17.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package erriter provides a way to iterate over an error tree.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func All added in v0.9.0

func All(err error) iter.Seq[error]

All returns an iter.Seq that iterates over an error tree recursively.

func FirstKeys added in v0.16.1

func FirstKeys[V any](seq iter.Seq2[string, V]) map[string]V

FirstKeys returns a map built from seq, where the first value is kept for each key.

func Unwrap added in v0.4.2

func Unwrap(err error) ([]error, error)

Unwrap unwraps an error.

If the error implements `Unwrap() error`, it returns the unwrapped error. If the error implements `Unwrap() []error`, it returns the unwrapped errors. Otherwise, it returns nil.

Types

This section is empty.

Jump to