errval

package
v0.3.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 28, 2023 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package errval provides a way to add values to errors.

Example
err := errbase.New("error")
err = Wrap(err, "foo", "bar")
vals := Get(err)
fmt.Println(vals["foo"])
Output:
bar

Index

Examples

Constants

This section is empty.

Variables

var VerboseStringer = func(v any) string {
	return fmt.Sprint(v)
}

VerboseStringer returns the string representation of a value in a verbose message.

It can be changed in order to customize how values are formatted.

Functions

func Get

func Get(err error) map[string]any

Get returns the values added to an error.

func Wrap

func Wrap(err error, key string, val any) error

Wrap adds a value to an error.

The verbose message is "value <key> = <val>". The value is written using the VerboseWriter function.

Types

This section is empty.

Jump to